==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkDialogPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkDialogPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class 4eb180ddb800c38a gnu_java_awt_peer_gtk_GtkContainerPeer
// @dep_class b0c680c45cabe4ec gnu_java_awt_peer_gtk_GtkDialogPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 3ef33a94bad58118 gnu_java_awt_peer_gtk_GtkWindowPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkWindowPeer

#include "gnu/java/awt/peer/gtk/GtkWindowPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkDialogPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkDialogPeer_H_

// Forward structure declarations
struct _jc_java_awt_Dialog$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$_init$905d0395627341fd(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, struct _jc_java_awt_Dialog$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *);
extern struct _jc_java_awt_Graphics$object *_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$postExposeEvent$68e41723d4a0c212(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, jint, jint, jint, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$postMouseEvent$bfd3491a34cebb53(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, jint, jlong, jint, jint, jint, jint, jboolean);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method_info$postExposeEvent$68e41723d4a0c212;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method_info$postMouseEvent$bfd3491a34cebb53;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *);
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *);
	void	(*postExposeEvent$68e41723d4a0c212)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, jint, jint, jint, jint);
	void	(*postMouseEvent$bfd3491a34cebb53)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, jint, jlong, jint, jint, jint, jint, jboolean);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkContainerPeer$vmethods	gnu_java_awt_peer_gtk_GtkContainerPeer;
	_jc_gnu_java_awt_peer_gtk_GtkWindowPeer$vmethods	gnu_java_awt_peer_gtk_GtkWindowPeer;
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vmethods	gnu_java_awt_peer_gtk_GtkDialogPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_refs	gnu_java_awt_peer_gtk_GtkDialogPeer;
    _jc_gnu_java_awt_peer_gtk_GtkWindowPeer$sub_refs	gnu_java_awt_peer_gtk_GtkWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_refs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkWindowPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkDialogPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkDialogPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkDialogPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkDialogPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkDialogPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class 4eb180ddb800c38a gnu_java_awt_peer_gtk_GtkContainerPeer
// @dep_class b0c680c45cabe4ec gnu_java_awt_peer_gtk_GtkDialogPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 3ef33a94bad58118 gnu_java_awt_peer_gtk_GtkWindowPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkWindowPeer

#include "gnu/java/awt/peer/gtk/GtkWindowPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkDialogPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkDialogPeer_H_

// Forward structure declarations
struct _jc_java_awt_Dialog$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$_init$905d0395627341fd(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, struct _jc_java_awt_Dialog$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Graphics$object *_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$getGraphics$77f02e8821861132(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$postExposeEvent$68e41723d4a0c212(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method$postMouseEvent$bfd3491a34cebb53(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, jint, jlong, jint, jint, jint, jint, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method_info$getGraphics$77f02e8821861132;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method_info$postExposeEvent$68e41723d4a0c212;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$method_info$postMouseEvent$bfd3491a34cebb53;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Graphics$object	*(*getGraphics$77f02e8821861132)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *) _JC_JCNI_ATTR;
	void	(*postExposeEvent$68e41723d4a0c212)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
	void	(*postMouseEvent$bfd3491a34cebb53)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object *, jint, jlong, jint, jint, jint, jint, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkContainerPeer$vmethods	gnu_java_awt_peer_gtk_GtkContainerPeer;
	_jc_gnu_java_awt_peer_gtk_GtkWindowPeer$vmethods	gnu_java_awt_peer_gtk_GtkWindowPeer;
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vmethods	gnu_java_awt_peer_gtk_GtkDialogPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_refs	gnu_java_awt_peer_gtk_GtkDialogPeer;
    _jc_gnu_java_awt_peer_gtk_GtkWindowPeer$sub_refs	gnu_java_awt_peer_gtk_GtkWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_refs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkWindowPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkDialogPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkDialogPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkDialogPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkDialogPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkDialogPeer_H_ */
